@@ -206,8 +206,8 @@ class Interaction(LibraryComponent):
         See `Fill Text` for other details.
 
         Example:
-        | Fill Secret    input#username_field    $username    # Keyword resolves variable value from Robot Framework variables
-        | Fill Secret    input#username_field    %username    # Keyword resolves variable value from environment variables
+        | `Fill Secret`    input#username_field    $username    # Keyword resolves variable value from Robot Framework variables
+        | `Fill Secret`    input#username_field    %username    # Keyword resolves variable value from environment variables
         """
         originals = self._get_original_values(locals())
         secret = self.resolve_secret(
@@ -233,8 +233,8 @@ class Interaction(LibraryComponent):
         [https://playwright.dev/docs/api/class-page#pagepressselector-key-options | Playwright docs for press.]
 
         Example:
-        | # Keyword       Selector                    *Keys
-        | Press Keys      //*[@id="username_field"]    h    e   l   o   ArrowLeft   l
+        | # Keyword         Selector                    *Keys
+        | `Press Keys`      //*[@id="username_field"]    h    e   l   o   ArrowLeft   l
         """  # noqa
         with self.playwright.grpc_channel() as stub:
             response = stub.Press(Request().PressKeys(selector=selector, key=keys))
@@ -319,22 +319,29 @@ class Interaction(LibraryComponent):
             logger.debug(response.log)
 
     @keyword(tags=("PageContent",))
-    def record_selector(self):
+    def record_selector(
+        self,
+        label: Optional[str] = None,
+    ):
         """Record the selector that is under mouse.
 
+        ``label`` text to show when on the box in the page while recording.
+
         Focus on the page and move mouse over the element you want to select.
-        Press 's' to store the elements selector.
 
         Example:
-        | ${recording} =    `Promise To`    `Record Selector`
-        | `Hover`    h1
-        | `Keyboard Key`    press    s
-        | ${selector} =    `Wait For`    ${recording}
+        | ${selector} =    `Record Selector`   Button
+        | `Click`  ${selector}
+        | ${selector2} =    `Record Selector`  Page header
+        | `Get Text`  ${selector2}  ==  Expected text
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.RecordSelector(Request.Empty())
+            response = stub.RecordSelector(Request.Label(label=label or ""))
             selector_repr = response.result.replace("#", "\\#")
-            logger.info(f"Selector: {selector_repr}")
+            logger.console(
+                f"\nSelector{' for ' + label if label else ''}: {selector_repr}"
+            )
+            logger.info(f"Selector{' for ' + label if label else ''}: {selector_repr}")
             return json.loads(response.result)
 
     @keyword(tags=("Setter", "PageContent"))
@@ -614,8 +621,8 @@ class Interaction(LibraryComponent):
             ``action`` equals accept. Defaults to empty string.
 
         Example:
-        | Handle Future Dialogs    action=accept
-        | Click                    \\#alerts
+        | `Handle Future Dialogs`    action=accept
+        | `Click`                    \\#alerts
         """
 
         with self.playwright.grpc_channel() as stub:
@@ -643,10 +650,10 @@ class Interaction(LibraryComponent):
 
         Example with returning text:
 
-        | ${promise} =       Promise To    Wait For Alert    action=accept
-        | Click              id=alerts
-        | ${text} =          Wait For      ${promise}
-        | Should Be Equal    ${text}       Am an alert
+        | ${promise} =         `Promise To`    `Wait For Alert`    action=accept
+        | `Click`              id=alerts
+        | ${text} =            `Wait For`      ${promise}
+        | Should Be Equal      ${text}         Am an alert
 
         Example with text verify:
 
@@ -858,11 +865,11 @@ class Interaction(LibraryComponent):
         ``Shift``, ``Control``, ``Alt``, ``Meta``, ``ShiftLeft``
 
         Example excecution:
-        | Keyboard Key    press    S
-        | Keyboard Key    down     Shift
-        | Keyboard Key    press    ArrowLeft
-        | Keyboard Key    press    Delete
-        | Keyboard Key    up       Shift
+        | `Keyboard Key`    press    S
+        | `Keyboard Key`    down     Shift
+        | `Keyboard Key`    press    ArrowLeft
+        | `Keyboard Key`    press    Delete
+        | `Keyboard Key`    up       Shift
 
         Note: Capital letters don't need to be written by the help of Shift. You can type them in directly.
         """
